@@ -1,7 +1,7 @@
 package Acme::ESP;
 use vars qw( $VERSION @EXPORT );
 BEGIN {
-    $VERSION= 1.001_006;
+    $VERSION= 1.002_001;
     @EXPORT= 8x0 .oO ;
     require Exporter;
     *import= \&Exporter::import;
@@ -11,11 +11,18 @@ use strict;
 
 sub oO
 {
+    @_= map {
+        my $i;
+        eval{%$_||1}?(!%$_?():( $i= $_, join ".  ", map
+            "$_: $$i{$_}", map substr("m;V",0,length) ^ $_, sort map
+            $_ ^ substr("m;V",0,length), keys %$i ) . "." ) :
+        eval{1+@$_}?(!@$_?(): join( "; ", @$_ ) ) : $_
+    } @_;
     my( $thought )= !@_ ? undef : join " ... ", @_;
     return bless \$thought, 'Acme::ESP::Scanner';
 }
 
-sub O'o { shift; oO( @_ ) }
+sub O'o { [ shift,oO( @_ ) ]->[!$[] }
 
 package Acme::ESP::Scanner;
 
@@ -24,21 +31,27 @@ use overload(
     nomethod => \&explode,
 );
 
-my $openMind= 1<<21;
-my $fmt= 'LLLL';
-{
+my $openMind= 1<<25;
+my $fmt= do {
     my $mind= "thoughts";
     $mind= \$mind;
     my( $p2, $rc, $f )=
         unpack "LLL", unpack "P12", pack "L", $mind;
     my $state= unpack "C", pack "V", $f;
-    $fmt= "LLLJ"    # Why does "LLJJ" work in cygwin?
-        if  eval { pack "J", 1; 1 };
-    if(  $state == 5  ) {
-        $openMind <<= 4;
-        $fmt= "x4" . $fmt;
+    my $pre= 'x4';
+    if(  $state == 4  ) {
+        $openMind >>= 4;
+        $pre= '';
     }
-}
+    my $last= "J";
+    my $size= eval { length( pack "J", 1 ) };
+    if(  ! defined $size  ) {
+        $last= "L";
+    } elsif(  4 < $size  &&  ! $pre  ) {
+        $last= "x4J";
+    }
+    $pre . "L3" . $last;
+};
 
 sub scan
 {
@@ -51,15 +64,16 @@ sub scan
         unpack "L4", unpack "P16", pack "L", $mind;
     if(  $openMind & $f  ) {
         my( $pv, $cur, $siz, $iv )=
-            unpack $fmt, unpack "P32", pack "L", $p2;
+            unpack $fmt, unpack "P24", pack "L", $p2;
         $pv= $p3
-            if  $fmt =~ /x/;
+            if  $fmt =~ /^x/;
         $secret= unpack "P$iv", pack "L", $pv-$iv;
     }
     bless $scanner, 'Acme::ESP';
     my $thought= $$scanner;
     if(  defined $thought  ) {
-        # It is surprising how hard it can be to clear your mind
+        # It is surprising how hard it can be to clear your mind.
+        # It'd be nice to do this less destructively.
         my $surface= "$$mind";
         $$mind= undef;
         $$mind= $thought . $surface;
@@ -88,19 +102,19 @@ Acme::ESP - The power to implant and extract strings' thoughts.
     my $string= "Nice hat.";
 
     # Implant a thought:
-    $string.oO( "What an ugly hat!" );
+    $string . o O ( "What an ugly hat!" );
 
     print $string;          # Prints "Nice hat."
 
     # Read a thought, leaving it in place:
-    print $string.oO( );    # Prints "What an ugly hat!"
+    print $string.oO{ };    # Prints "What an ugly hat!"
 
     # Read a thought, replacing it:
-    print $string . o O ( "Did I say that out loud?!" );
+    print $string.oO("Did I say that out loud?!");
     # Prints "What an ugly hat!"
 
     # Empty their mind:
-    print $string.oO( '' );
+    print $string . o O [ '' ];
     # Prints "Did I say that out loud?!"
 
 =head1 DESCRIPTION
@@ -115,6 +129,11 @@ thought.
 Some platforms are skeptical and interfere with the extraction of
 stored thoughts.
 
+Pointed thoughts are not demonstrated above because of their quirks.
+They never leave previous thoughts intact, may transform strangely
+or be unreasonably literal, and (due to a Perl design flaw) may even
+impact the surrounding environment (deleting files, etc.).
+
 =head1 CONTRIBUTORS
 
 Author: Tye McQueen, http://perlmonks.org/?node=tye
@@ -122,7 +141,7 @@ Author: Tye McQueen, http://perlmonks.org/?node=tye
 http://perlmonks.org/?node=Corion appears to have implanted the idea
 into my brain.
 
-http://perlmonks.org/?node=jZed inspired much of the test suite.
+http://perlmonks.org/?node=jZed inspired the initial test suite.
 
 http://perlmonks.org/?node=Anno suggested the support for more drawn-out
 thoughts.
